function [ret,x0,str,ts,xts]=kaoss(t,x,u,flag);
%KAOSS	is the M-file description of the SIMULINK system named KAOSS.
%	The block-diagram can be displayed by typing: KAOSS.
%
%	SYS=KAOSS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes KAOSS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling KAOSS with a FLAG of zero:
%	[SIZES]=KAOSS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,440])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '[t2,x1,x2,x3]')

add_block('built-in/Note',[sys,'/',['A Lorenz egyenlet SIMULINK programvazlata',13,'',13,'dx1//dt = 10(x2 - x1)',13,'dx2//dt = -x1x3 + 28x1 - x2',13,'dx3//dt = x1x2 - 8x3//3']])
set_param([sys,'/',['A Lorenz egyenlet SIMULINK programvazlata',13,'',13,'dx1//dt = 10(x2 - x1)',13,'dx2//dt = -x1x3 + 28x1 - x2',13,'dx3//dt = x1x2 - 8x3//3']],...
		'position',[215,560,410,565])

add_block('built-in/Product',[sys,'/','Product1'])
set_param([sys,'/','Product1'],...
		'orientation',2,...
		'Drop Shadow',4,...
		'position',[220,134,255,161])


%     Subsystem  ['Auto-Scale',13,'Graph2'].

new_system([sys,'/',['Auto-Scale',13,'Graph2']])
set_param([sys,'/',['Auto-Scale',13,'Graph2']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph2/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph2/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph2/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph2/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Auto-Scale',13,'Graph2']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Entries','10\/-50\/50\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Auto-Scale',13,'Graph2'].

set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'orientation',2,...
		'position',[305,185,335,225])


%     Subsystem  'x1x3Graph'.

new_system([sys,'/','x1x3Graph'])
set_param([sys,'/','x1x3Graph'],'Location',[8,52,282,245])

add_block('built-in/Inport',[sys,'/','x1x3Graph/y'])
set_param([sys,'/','x1x3Graph/y'],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/','x1x3Graph/x'])
set_param([sys,'/','x1x3Graph/x'],...
		'position',[10,30,30,50])

add_block('built-in/Mux',[sys,'/','x1x3Graph/Mux'])
set_param([sys,'/','x1x3Graph/Mux'],...
		'inputs','2',...
		'position',[100,61,130,94])

add_block('built-in/S-Function',[sys,'/',['x1x3Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['x1x3Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxy',...
		'parameters','ax, st',...
		'position',[185,70,235,90])
add_line([sys,'/','x1x3Graph'],[35,110;70,110;70,85;95,85])
add_line([sys,'/','x1x3Graph'],[35,40;70,40;70,70;95,70])
add_line([sys,'/','x1x3Graph'],[135,80;180,80])
set_param([sys,'/','x1x3Graph'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','x1x3Graph'],...
		'Mask Type','XY scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min:|x-max:|y-min:|y-max:')
set_param([sys,'/','x1x3Graph'],...
		'Mask Translate','ax = [@1, @2, @3, @4];st=-1;',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxy.m to see how it works.',...
		'Mask Entries','-20\/20\/5\/45\/')


%     Finished composite block 'x1x3Graph'.

set_param([sys,'/','x1x3Graph'],...
		'orientation',3,...
		'position',[605,185,640,225])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'orientation',2,...
		'mat-name','x2',...
		'buffer','1001',...
		'position',[300,255,350,275])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'orientation',2,...
		'Drop Shadow',4,...
		'Gain','-1',...
		'position',[285,465,315,495])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'orientation',2,...
		'Drop Shadow',4,...
		'Gain','28',...
		'position',[285,415,315,445])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'orientation',2,...
		'Drop Shadow',4,...
		'Gain','8/3',...
		'position',[120,360,150,390])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'orientation',2,...
		'Drop Shadow',4,...
		'Gain','10',...
		'position',[470,380,500,410])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'Drop Shadow',4,...
		'Gain','10',...
		'position',[395,337,420,363])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'Drop Shadow',4,...
		'inputs','+-',...
		'position',[445,345,465,365])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'Drop Shadow',4,...
		'Initial','10',...
		'position',[495,345,515,365])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'Drop Shadow',4,...
		'inputs','++-',...
		'position',[290,328,310,372])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'Drop Shadow',4,...
		'inputs','+-',...
		'position',[105,320,125,340])

add_block('built-in/Product',[sys,'/','Product2'])
set_param([sys,'/','Product2'],...
		'Drop Shadow',4,...
		'position',[225,323,255,347])

add_block('built-in/Integrator',[sys,'/','Integrator3'])
set_param([sys,'/','Integrator3'],...
		'Drop Shadow',4,...
		'Initial','30',...
		'position',[145,320,165,340])

add_block('built-in/Integrator',[sys,'/','Integrator2'])
set_param([sys,'/','Integrator2'],...
		'Drop Shadow',4,...
		'Initial','20',...
		'position',[335,340,355,360])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'orientation',2,...
		'mat-name','x1',...
		'buffer','1001',...
		'position',[430,255,480,275])


%     Subsystem  ['Auto-Scale',13,'Graph1'].

new_system([sys,'/',['Auto-Scale',13,'Graph1']])
set_param([sys,'/',['Auto-Scale',13,'Graph1']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph1/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph1/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph1/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Auto-Scale',13,'Graph1']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
		'Mask Entries','10\/-20\/20\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Auto-Scale',13,'Graph1'].

set_param([sys,'/',['Auto-Scale',13,'Graph1']],...
		'orientation',2,...
		'position',[440,185,470,225])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'mat-name','x3',...
		'buffer','1001',...
		'position',[220,255,270,275])


%     Subsystem  ['Auto-Scale',13,'Graph3'].

new_system([sys,'/',['Auto-Scale',13,'Graph3']])
set_param([sys,'/',['Auto-Scale',13,'Graph3']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph3/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph3/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph3/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph3/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Auto-Scale',13,'Graph3']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph3']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph3']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Auto-Scale',13,'Graph3']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Auto-Scale',13,'Graph3']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph3']],...
		'Mask Entries','10\/-30\/30\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Auto-Scale',13,'Graph3'].

set_param([sys,'/',['Auto-Scale',13,'Graph3']],...
		'position',[230,185,260,225])
add_line(sys,[130,330;140,330])
add_line(sys,[170,330;220,330])
add_line(sys,[260,335;285,335])
add_line(sys,[315,350;330,350])
add_line(sys,[360,350;390,350])
add_line(sys,[425,350;440,350])
add_line(sys,[470,355;490,355])
add_line(sys,[520,355;540,355;540,395;505,395])
add_line(sys,[465,395;430,395;440,360])
add_line(sys,[520,355;550,355;550,430;320,430])
add_line(sys,[170,330;180,330;180,375;155,375])
add_line(sys,[115,375;90,375;100,335])
add_line(sys,[215,150;90,150;100,325])
add_line(sys,[520,355;560,355;560,480;320,480])
add_line(sys,[280,480;200,480;200,340;220,340])
add_line(sys,[280,430;265,430;265,350;285,350])
add_line(sys,[520,355;615,355;615,230])
add_line(sys,[170,330;190,330;190,520;630,520;630,230])
add_line(sys,[360,350;370,350;370,395;270,395;270,365;285,365])
add_line(sys,[360,350;370,350;370,155;260,155])
add_line(sys,[360,350;370,350;370,205;340,205])
add_line(sys,[520,355;540,355;540,265;485,265])
add_line(sys,[520,355;540,355;540,205;475,205])
add_line(sys,[520,355;560,355;560,140;260,140])
add_line(sys,[360,350;370,350;370,265;355,265])
add_line(sys,[170,330;190,330;190,265;215,265])
add_line(sys,[170,330;190,330;190,205;225,205])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
