echo on
%KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
%
%               Szabalyozott villamos hajtas vizsgalata
%                     (Fordulatszam szabalyozas)
%               ======================================= 
%
%                         dx/dt=A*x+B*u 
%                             y=C*x+D*u
%                         -------------
% A rendszer allapotegyenletei:
%
%                   dx1/dt=(x2-kz*u2)/Tm
%                   dx2/dt={-x1-x2+kp*[x3+kc*(u1-x1)]}/Tv
%                   dx3/dt=[kc*(u1-x1)]/Ti
%                       y1=x1
%                       y2=x2
%                       y3=kc*(u1-x1)+x3             
%
% A parametermatrixok:
%        | 0              1/Tm  0     |        | 0        -kz/Tm |
%    A = |-(1+kc*kp)/Tv  -1/Tv  kp/Tv |    B = | kc*kp/Tv  0     |
%        |-kc/Ti          0     0     |        | kc/Ti     0     |
%
%        | 1   0   0 |                         | 0   0 |
%    C = | 0   1   0 |                     D = | 0   0 |
%        |-kc  0   1 |                         | kc  0 |
% 
pause;
%x1=w:szogsebesseg, x2=i:armatura-aram,  x3:a PI szabalyozo I csatornajanak
%kimeno jele; y1=w:szogsebesseg(a szabalyozottjellemzo),y2=i:armatura-aram,
%y3=e:kapecsfeszultseg (iranyito jel); u1=ua:alapjel (a szogsebesseg kivant
%erteke),u2=mt:zavaro jellemzo; kp,kz,Tm,Tv a folyamat (egyenaramu motor)-,
%a kc,Ti pedig a PI szabalyozo (visszacsatolt muveleti erosito) parameterei
%
%==========================================================================
%                           vhv.m fajl                                  szb
%  (parameteratadassal hasznalhato Simulink fajlok: szervos.m es vhvs.m)
pause;
%==========================================================================
%==========================================================================
% Adatbevitel:
%
kp=1;kz=.5;Tm=20;Tv=1;        % A  folyamat (egyenaramu motor)  parameterei
kc=1;Ti=5;                    % A PI szabalyozo parameterei(alapertelmezes)
kc=input('kc=');Ti=input('Ti=');              % A PI szabalyozo parameterei
%==========================================================================
% 1.) A rendszer parametermatrixai (A=a;B=b;C=c;D=d) es az
%     egyensulyi  pont allapot-  es kimeno jel koordinatai
%     
a=[0 1/Tm 0;-(1+kc*kp)/Tv -1/Tv kp/Tv;-kc/Ti 0 0];        %   Allapotmatrix
b=[0 -kz/Tm;kc*kp/Tv 0;kc/Ti 0];                          % Bemeneti matrix
c=[1 0 0;0 1 0;-kc 0 1];                                  % Kimeneti matrix
d=[0 0;0 0;kc 0];
printsys(a,b,c,d,['u1=ua u2=mt'],['y1=w y2=i y3=e'],['x1=w x2=i x3']);
pause;
p=eig(a);disp(p);                           % Az allapotmatrix sajatertekei
uao=1;mto=1;
uo=[uao mto]';                      % Az  allando  erteku  gerjeszto  jelek
xveg=-inv(a)*b*uo;                  % Az allapotvaltozok egyensulyi ertekei
yveg=(-c*inv(a)*b+d)*uo;            % A  kimeno  jelek  egyensulyi  ertekei
disp(yveg);pause;
%==========================================================================
% 2.) Stabilitasvizsgalat
%
pol=poly(a);                                   % A karakterisztikus polinom
p1=roots(poly(a));                             % A rendszer polusai (p1=p!)
disp(p1);pause;
Tii=0.95*Tv:.001*Tv:1.05*Tv;
kckrt=Tii./(kp*(Tv-Tii));                            % A kckrt(Ti) fuggveny
plot(Tii,kckrt,Tii,zeros(1,length(Tii)));grid;
xlabel('Ti');ylabel('kckrt');
title('A kc-Ti parametersik stabilis-labilis tartomanyai');pause;
%==========================================================================
% 3.) Az allapotegyenlet megoldasa  adott 
%                   ua(t)=1-exp(-t/20) es 
%                   mt(t)=1(t-100)
%     gerjeszto jelekre, zerus kezdeti feltetelek eseten
%
%              Az u1=ua(t) es u2=mt(t) gerjeszto jelek eloallitasa
t=0:0.1:200;                                  % A vizsgalat idointervalluma
u1=1-exp(-t/20);                                             % Az   alapjel 
u2=[zeros(1,1001),ones(1,1000)];                             % A zavaro jel
plot(t,u1,t,u2);
title('Az u1=ua es u2=mt gerjeszto jelek idofuggvenyei');
xlabel('t(ido)');ylabel('u1=ua; u2=mt');grid;pause;
u=[u1;u2]';
%              Az allapotegyenlet megoldasa
lsim(a,b,c,d,u,t);
title('A zart rendszer kimeno jelei');
xlabel('t(ido)');ylabel('y1=w,y2=i,y3=e');grid;pause;
[y,x]=lsim(a,b,c,d,u,t);
ymax=max(y)                                      % wmax imax emax szamitasa
plot(t,u1,t,y(:,1));
xlabel('t(ido)');ylabel('u1=ua; y1=w');
title('Az u1=ua alapjel es az y1=w szabalyozott jellemzo');grid;pause;
plot(t,u1'-y(:,1));
title('A h=ua-w hibajel idofuggvenye');
xlabel('t(ido)');ylabel('h=ua-w');grid;pause;
%==========================================================================
% 4.) A szabalyozo  es  a  folyamat  atmeneti  fuggvenyei,
%     a  nyitott   kor  atviteli  fuggvenyenek  amplitudo-
%     es fazismenete valamint  polus - zerus eloszlasa, es
%     a zart kor gyokhelygorbeje
%
mc=kc*[Ti 1];nc=[Ti 0];                                        %   Wc=mc/nc
step(mc,nc);                                                   %      vc(t)
grid;title('A szabalyozo vc(t) atmeneti fuggvenye');                
xlabel('t(ido)');ylabel('vc(t)');pause;
mp=kp;np=[Tm*Tv Tm 1];                                         %   Wp=mp/np
mpz=kz*[Tv 1];npz=np;                                          % Wz=mpz/npz
subplot(2,1,1);
step(mp,np);                                                   %      vp(t)
title('A folyamat em=1(t)-re vonatkozo atmeneti fuggvenye');
xlabel('');ylabel('w(t)');grid;
subplot(2,1,2);
step(-mpz,npz);                                                %     vpz(t)
title('A folyamat mt=1(t)-re vonatkozo atmeneti fuggvenye');
xlabel('t(ido)');ylabel('w(t)');grid;pause;
[mo,no]=series(mc,nc,mp,np);                                   %   Wo=Wc*Wp
[at,ft,wt,wc]=margin(mo,no);                                         disp([ft wc]);pause;           % Wo fazistobblete es vagasi korfrekvenciaja
margin(mo,no);pause;
nyquist(mo,no,.5*wc:.01*wc:1.5*wc);
title('A Wo(jw) helygorbe az wc vagasi korfrekvencia kornyezeteben');
grid;pause;
pzmap(mo,no);
grid;title('Wo(s) polus-zerus eloszlasa');pause;
rlocus(mo,no);grid;title('A zart rendszer gyokhelygorbeje');pause;
%==========================================================================
% 5.) Kulonfele atviteli- es atmeneti fuggvenyek valamint
%     a  zart  rendszer  ht  tullendulesenek  szamitasa
%
[mwa,nwa]=cloop(mo,no);                               % W=Wo/(1+Wo)=mwa/nwa
[maj,naj]=ss2tf(a,b,c,d,1);                           %      w/ua;i/ua;e/ua
[mzj,nzj]=ss2tf(a,b,c,d,2);                           %      w/mt;i/mt;e/mt
subplot(2,1,1);
step(a,b,c,d,1);
title('A zart rendszer ua=1(t) alapjelre vonatkozo atmeneti fuggvenyei');
xlabel('');ylabel('y1=w;y2=i;y3=e');grid;
subplot(2,1,2);
step(a,b,c,d,2);
title('A zart rendszer mt=1(t) zavarojelre vonatkozo atmeneti fuggvenyei');
xlabel('t(ido)');ylabel('y1=w;y2=i;y3=e');grid;pause;clg;
[mea,nea]=feedback(mc,nc,mp,np);                              %   Wc/(1+Wo)
[mha,nha]=feedback(1,1,mo,no);                                %    1/(1+Wo)
[mwz,nwz]=series(-mpz,npz,mha,nha);                           %  -Wz/(1+Wo)
[me,ne]=series(mpz,npz,mc,nc);                                %        WzWc
[mez,nez]=series(me,ne,mha,nha);                              % WzWc/(1+Wo)
step(mwa,nwa);
title('A zart szabalyozas ua=1(t)-re vonatkozo eredo atmeneti fuggvenye');
xlabel('t(ido)');ylabel('v(t)=y1(t)=w(t)');grid;pause;
wv=step(mwa,nwa);
wmax=max(wv);ht=100*(wmax-1);disp(ht);pause;clg;            % A tullendules
%==========================================================================
disp('Az analizis jellegu feladatmegoldasok vege');
                     % Tovabbi  vizsgalatok  a billentyuzetrol majd RETURN
                     % (vhv.m ujrahivasa, simulink szervos.m behivasa, stb)
keyboard;                                     
%==========================================================================
%==========================================================================
% 6.) A szabalyozo rendszertechnikai meretezese
%     (Szintezis jellegu feladatok) 
%
%     a.) Folytonos szabalyozo meretezese fazistobbletre 
%         Eloiras: pi+arcWo(jwc)=ft fazistobblet
%         ----------------------------------------------------
ft=input('ft=');                                   % ft:radian
T1=Tm*(1+sqrt(1-4*Tv/Tm))/2;
T2=Tm*(1-sqrt(1-4*Tv/Tm))/2;                       % A folyamat idoallandoi
Ti=T1;
wc=tan(pi/2-ft)/T2;
kc=T1*tan(pi/2-ft)*sqrt(1+(tan(pi/2-ft))^2)/T2;
disp([kc Ti]);pause;
%-------------------
% Ellenorzo szamitasok
mc=kc*[Ti 1];nc=[Ti 0];                                         %     Wc(s)
[mo,no]=series(mc,nc,mp,np);                                    %   Wo=WcWp
pzmap(mo,no);
grid;title('Wo(s) polus-zerus eloszlasa');pause;
margin(mo,no);pause;
rlocus(mo,no);grid;title('A zart rendszer gyokhelygorbeje');pause;
[mwa,nwa]=cloop(mo,no);                                         % Wo/(1+Wo)
[mea,nea]=feedback(mc,nc,mp,np);                                % Wc/(1+Wo)
pzmap(mwa,nwa);
grid;title('Wo/(1+Wo) polus-zeruus eloszlasa');pause;
subplot(2,1,1);
step(mwa,nwa);
grid;title('A zart szabalyozas atmeneti fuggvenye (ft=60 fok)');
xlabel('');ylabel('w(t)');
subplot(2,1,2);
step(mea,nea);
grid;title('Az iranyito jel');
xlabel('t(ido)');ylabel('e(t)');pause;clg;
wv=step(mwa,nwa);
wmax=max(wv);ht=100*(wmax-1);disp(ht);pause; % A zart rendszer tullendulese
printsys(mc,nc,'s');pause;                                    % Wc(s)=mc/nc
keyboard;                             % (pl simulink szervos.m hivasa, stb)
%
%      b.) Folytonos szabalyozo meretezese tullendulesre 
%          Eloiras: A zart rendszer atmeneti fuggvenyenek ht tullendulese
%          --------------------------------------------------------------
ht=input('ht=');                              % A tullendules eloirt erteke
kc=(T1/(4*T2*kp))*(1+(pi/log(ht))^2);
disp([kc Ti]);pause;
%-------------------
% Ellenorzo szamitasok
mc=kc*[Ti 1];
[mo,no]=series(mc,nc,mp,np);
pzmap(mo,no);
grid;title('Wo(s) polus-zerus eloszlasa');pause;
rlocus(mo,no);grid;title('A zart szabalyozas gyokhelygorbeje');pause;
[a,f,w]=bode(mo,no);
[at,ft,wt,wc]=margin(a,f,w);disp([ft wc]);pause;         % ft=pi+arcWo(jwc) 
[mwa,nwa]=cloop(mo,no);
[mea,nea]=feedback(mc,nc,mp,np);
pzmap(mwa,nwa);
grid;title('Wo/(1+Wo) polus zerus eloszlasa');pause;
wv=step(mwa,nwa);
wmax=max(wv);hts=100*(wmax-1);disp(hts);pause;        % ht tenyleges erteke
subplot(2,1,1);
step(mwa,nwa);
grid;title('A zart rendszer atmeneti fuggvenye (meretezes eloirt ht-re)');
xlabel('');ylabel('w(t)');
subplot(2,1,2);
step(mea,nea);
grid;title('Az e(t) iranyitojel');
xlabel('t(ido)');ylabel('e(t)');pause;clg;
margin(mo,no);pause;       % Wo(jw) fazistobblete es vagasi korfrekvenciaja
step(mc,nc);grid;title('A szabalyozo atmeneti fuggvenye');
xlabel('t(ido)');ylabel('vc(t)');pause;
printsys(mc,nc,'s');pause
keyboard;                             % (pl simulink szervos.m hivasa, stb)
%
%      c.) Kvazifolytonos diszkret szabalyozo meretezese
%          Eloiras: a folytonos rendszerhez hasonlo mukodes
%          ------------------------------------------------
dft=input('dft=');                  % A megengedett dft  fazistobbletromlas
Tsa=dft*pi/90/wc;disp(Tsa);         % A mintavetelezesi ido ajanlott erteke
Ts=input('Ts=');                    % A tenyleges  Ts  mintavetelezesi  ido
[mcd,ncd]=c2dm(mc,nc,Ts);                                          % Wcd(z)
printsys(mcd,ncd,'z');pause;
%------------------------
% Ellenorzo szamitasok
dstep(mcd,ncd,100);grid;title('A DDC szabalyozo atmeneti fuggvenye');
xlabel('k=t/Ts');ylabel('vcd(k)');pause;
[mpd,npd]=c2dm(mp,np,Ts);                                          % Wpd(z)
[mod,nod]=series(mcd,ncd,mpd,npd);                      %     Wod(z)=WcdWpd
[ad,fd,w]=dbode(mod,nod,Ts);                            %  absWod;   arcWod
[atd,ftd,wtd,wcd]=margin(ad,fd,w);disp([ftd wcd]);pause;%ftd=pi+arcWod(jwc)
[mwad,nwad]=cloop(mod,nod);                             % Wd(z)=Wod/(1+Wod)
[mead,nead]=feedback(mcd,ncd,mpd,npd);                        % Wcd/(1+Wod)
subplot(2,1,1);
dstep(mwad,nwad,100);grid;title('A szabalyozott jellemzo');
xlabel('');ylabel('wd(k)');
subplot(2,1,2);
dstep(mead,nead,100);grid;title('Az iranyito jel');
xlabel('k=t/Ts');ylabel('ed(k)');pause;clg;
wd=dstep(mwad,nwad,100);
wdmax=max(wd);ht=100*(wdmax-1);disp(ht);pause;
keyboard;                                % (pl simulink vhvs.m hivasa, stb)
%
%      d.) DDC szabalyozo meretezese diszkret modell alapjan
%          Eloiras: pi+Wod(exp(jwcTs))=pi/3 (ftd=60 fok fazistobblet)
%          ----------------------------------------------------------
Tsa=[Tm/25 Tm/12]             % A mintavetelezesi ido ajanlott intervalluma
Ts=input('Ts=');                          % A tenyleges mintavetelezesi ido
[mpd,npd]=c2dm(mp,np,Ts);
mcd=[1 -exp(-Ts/T1)];ncd=[1 -1];                                    % kcd=1
[mod,nod]=series(mcd,ncd,mpd,npd);
dbode(mod,nod,Ts);pause;
for i=1:3
wmin(i)=input('wmin(i)=');wmax(i)=input('wmax(i)=');
w=linspace(wmin(i),wmax(i),20);
[ad,fd,w]=dbode(mod,nod,Ts,w);
[w' fd ad]
end
adwc=input('adwc=');
kcd=1/adwc;mcd=kcd*mcd;
printsys(mcd,ncd,'z');pause;                               % Wcd(z)=mcd/ncd
%---------------------------
% Ellenorzo szamitasok
[mod,nod]=series(mcd,ncd,mpd,npd);                         %     Wod=WcdWpd
[ad,fd,w]=dbode(mod,nod,Ts);
[atd,ftd,wtd,wcd]=margin(ad,fd,w);disp([ftd wcd]);pause;
[mwad,nwad]=cloop(mod,nod);                         % Wod/(1+Wod)=mwad/nwad
[mead,nead]=feedback(mcd,ncd,mpd,npd);              % Wcd/(1+Wod)=mwad/nead
subplot(2,1,1);
dstep(mwad,nwad,20);grid;title('A zart szabalyozas yd atmeneti fuggvenye');
xlabel('');ylabel('yd(k)');
subplot(2,1,2);
dstep(mead,nead,20);grid;title('A zart szabalyozas iranyito jele');
xlabel('k=t/Ts');ylabel('eT(k)');pause;clg;
keyboard;                                % (pl simulink vhvs.m hivasa, stb)
%
%      e.) Veges beallast biztosito DB szabalyozo meretezese
%          Eloiras: A szabalyozott jellemzo 2Ts ido alatti veges beallasa
%          --------------------------------------------------------------
utm=input('utmax=');                     % A megengedett tulvezerlesi arany
Ts=linspace(.5*Tv,5*Tv,100);
ut=1./((1-exp(-Ts/T1)).*(1-exp(-Ts/T2)));
plot(Ts,ut,Ts,utm*ones(1,length(Ts)));grid;
title('Az ut(Ts) fuggveny grafikonja');xlabel('Ts');ylabel('ut');pause;
for i=1:3
Tsmin(i)=input('Tsmin(i)=');Tsmax(i)=input('Tsmax(i)=');
Ts=linspace(Tsmin(i),Tsmax(i),20);
ut=1./((1-exp(-Ts/T1)).*(1-exp(-Ts/T2)));
[Ts' ut']
end
Ts=input('Ts=');                          % A tenyleges mintavetelezesi ido
[mpd,npd]=c2dm(mp,np,Ts);
mcd=npd;
ncd=[polyval(mpd,1) -mpd(2) -mpd(3)];
printsys(mcd/ncd(1),ncd/ncd(1),'z');pause;         % Wcd(z) (DB algoritmus)
%-----------------------------------------
% Ellenorzo szamitasok
dstep(mcd,ncd,10);title('A DB szabalyozo atmeneti fuggvenye');
xlabel('k=t/Ts');ylabel('vcd(k)');grid;pause;
[mod,nod]=series(mcd,ncd,mpd,npd);                            %  Wod=WcdWpd
[ad,fd,w]=dbode(mod,nod,Ts);
[atd,ftd,wtd,wcd]=margin(ad,fd,w);
disp([ftd wcd]);pause;               % Fazistobblet es vagasi korfrekvencia
[mwad,nwad]=cloop(mod,nod);                                   % Wod/(1+Wod)
[mead,nead]=feedback(mcd,ncd,mpd,npd);                        % Wcd/(1+Wod)
subplot(2,1,1);
dstep(mwad,nwad,5);title('A szabalyozott jellemzo diszkret ertekei');
xlabel('');ylabel('wd(k)');grid;
subplot(2,1,2);
dstep(mead,nead,5);title('Az iranyito jel diszkret ertekei');
xlabel('k=t/Ts');ylabel('eT(k)');grid;pause;clg;
e=dstep(mead,nead,3);
ei=[e(1)*ones(1,100) e(2)*ones(1,100) e(3)*ones(1,100)];
ti=linspace(0,3*Ts,300);
lsim(mp,np,ei,ti);hold;
plot(ti,ei/e(1));title('Az w(t) es eT(t) jelek idofuggvenyei');
xlabel('t(ido)');ylabel('w es eT/umax');grid;pause;clg;
keyboard;                                % (pl simulink vhvs.m hivasa, stb)
%==========================================================================
disp('A szintezis jellegu feladatmegoldasok vege');
%==========================================================================
%==========================================================================
disp('A vizsgalat vege')
%VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV 