function [ret,x0,str,ts,xts]=vhvs(t,x,u,flag);
%VHVS	is the M-file description of the SIMULINK system named VHVS.
%	The block-diagram can be displayed by typing: VHVS.
%
%	SYS=VHVS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes VHVS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling VHVS with a FLAG of zero:
%	[SIZES]=VHVS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[8,100,616,384])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '200')
set_param(sys,'Min step size', 'Ts')
set_param(sys,'Max step size', 'Ts')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '[t2,e,i,w]')

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn w'])
set_param([sys,'/','Transfer Fcn w'],...
		'Drop Shadow',4,...
		'Denominator','[Tm 0]',...
		'position',[475,157,510,193])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'Drop Shadow',4,...
		'inputs','-+',...
		'position',[430,165,450,185])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'Drop Shadow',4,...
		'inputs','+--',...
		'position',[295,158,310,202])

add_block('built-in/Zero-Order Hold',[sys,'/',['Zero-Order',13,'Hold']])
set_param([sys,'/',['Zero-Order',13,'Hold']],...
		'Drop Shadow',4,...
		'Sample time','Ts',...
		'position',[160,149,195,181])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn PI ']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn PI ']],...
		'Drop Shadow',4,...
		'Numerator','mcd',...
		'Denominator','ncd',...
		'Sample time','Ts',...
		'position',[90,147,135,183])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'Drop Shadow',4,...
		'inputs','+-',...
		'position',[45,155,65,175])

add_block('built-in/To Workspace',[sys,'/','iranyitojel'])
set_param([sys,'/','iranyitojel'],...
		'mat-name','e',...
		'buffer','2001',...
		'position',[225,97,275,113])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn i'])
set_param([sys,'/','Transfer Fcn i'],...
		'Drop Shadow',4,...
		'Denominator','[Tv  0]',...
		'position',[330,162,365,198])

add_block('built-in/To Workspace',[sys,'/','armaturaaram'])
set_param([sys,'/','armaturaaram'],...
		'orientation',2,...
		'mat-name','i',...
		'buffer','2001',...
		'position',[320,95,370,115])


%     Subsystem  ['Auto-Scale',13,'Graph i'].

new_system([sys,'/',['Auto-Scale',13,'Graph i']])
set_param([sys,'/',['Auto-Scale',13,'Graph i']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph i/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph i/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph i/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph i/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Auto-Scale',13,'Graph i']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph i']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph i']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Auto-Scale',13,'Graph i']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Auto-Scale',13,'Graph i']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph i']],...
		'Mask Entries','200\/-1\/1.50\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Auto-Scale',13,'Graph i'].

set_param([sys,'/',['Auto-Scale',13,'Graph i']],...
		'orientation',2,...
		'position',[330,15,360,55])


%     Subsystem  ['Auto-Scale',13,'Graph e'].

new_system([sys,'/',['Auto-Scale',13,'Graph e']])
set_param([sys,'/',['Auto-Scale',13,'Graph e']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph e/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph e/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph e/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph e/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Auto-Scale',13,'Graph e']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph e']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph e']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Auto-Scale',13,'Graph e']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Auto-Scale',13,'Graph e']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph e']],...
		'Mask Entries','200\/-5\/10\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Auto-Scale',13,'Graph e'].

set_param([sys,'/',['Auto-Scale',13,'Graph e']],...
		'position',[235,15,265,55])


%     Subsystem  ['Auto-Scale',13,'Graph w'].

new_system([sys,'/',['Auto-Scale',13,'Graph w']])
set_param([sys,'/',['Auto-Scale',13,'Graph w']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph w/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph w/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph w/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph w/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Auto-Scale',13,'Graph w']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph w']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph w']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Auto-Scale',13,'Graph w']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Auto-Scale',13,'Graph w']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph w']],...
		'Mask Entries','200\/0\/1.50\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Auto-Scale',13,'Graph w'].

set_param([sys,'/',['Auto-Scale',13,'Graph w']],...
		'position',[555,15,585,55])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'Gain','kp',...
		'position',[225,152,250,178])

add_block('built-in/To Workspace',[sys,'/','      szogsebesseg'])
set_param([sys,'/','      szogsebesseg'],...
		'mat-name','w',...
		'buffer','2001',...
		'position',[540,97,590,113])

add_block('built-in/Step Fcn',[sys,'/','Step mt'])
set_param([sys,'/','Step mt'],...
		'orientation',1,...
		'Drop Shadow',4,...
		'Time','100',...
		'After','.5',...
		'position',[405,30,425,50])

add_block('built-in/Transfer Fcn',[sys,'/','eloszuro'])
set_param([sys,'/','eloszuro'],...
		'orientation',1,...
		'Drop Shadow',4,...
		'Denominator','[20 1]',...
		'position',[5,85,45,125])

add_block('built-in/Step Fcn',[sys,'/','Step ua'])
set_param([sys,'/','Step ua'],...
		'orientation',1,...
		'Drop Shadow',4,...
		'Time','0',...
		'position',[15,25,35,45])

add_block('built-in/Note',[sys,'/','Hibrid szabalyozas Simulink programvazlata'])
set_param([sys,'/','Hibrid szabalyozas Simulink programvazlata'],...
		'position',[150,259,390,281])
add_line(sys,[455,175;470,175])
add_line(sys,[370,180;425,180])
add_line(sys,[315,180;325,180])
add_line(sys,[255,165;290,165])
add_line(sys,[200,165;220,165])
add_line(sys,[140,165;155,165])
add_line(sys,[70,165;85,165])
add_line(sys,[515,175;535,175;535,250;265,250;265,180;290,180])
add_line(sys,[515,175;545,175;545,275;15,275;15,170;40,170])
add_line(sys,[415,55;425,170])
add_line(sys,[370,180;385,180;385,225;280,225;290,195])
add_line(sys,[370,180;385,180;375,105])
add_line(sys,[370,180;385,180;385,35;365,35])
add_line(sys,[200,165;200,105;220,105])
add_line(sys,[200,165;200,35;230,35])
add_line(sys,[515,175;515,35;550,35])
add_line(sys,[515,175;515,105;535,105])
add_line(sys,[25,50;25,80])
add_line(sys,[25,130;25,160;40,160])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
